==> kibana-7.6.2p0.tgz: kibana/src/core/server/saved_objects/service/lib/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ISavedObjectsRepository", {
  enumerable: true,
  get: function () {
    return _repository.ISavedObjectsRepository;
  }
});
Object.defineProperty(exports, "SavedObjectsRepository", {
  enumerable: true,
  get: function () {
    return _repository.SavedObjectsRepository;
  }
});
Object.defineProperty(exports, "SavedObjectsClientWrapperFactory", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientWrapperFactory;
  }
});
Object.defineProperty(exports, "SavedObjectsClientWrapperOptions", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientWrapperOptions;
  }
});
Object.defineProperty(exports, "ISavedObjectsClientProvider", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.ISavedObjectsClientProvider;
  }
});
Object.defineProperty(exports, "SavedObjectsClientProvider", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientProvider;
  }
});
Object.defineProperty(exports, "SavedObjectsClientProviderOptions", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientProviderOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsClientFactory", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientFactory;
  }
});
Object.defineProperty(exports, "SavedObjectsErrorHelpers", {
  enumerable: true,
  get: function () {
    return _errors.SavedObjectsErrorHelpers;
  }
});

var _repository = require("./repository");

var _scoped_client_provider = require("./scoped_client_provider");

var _errors = require("./errors");

==> kibana-7.9.1.tgz: kibana/src/core/server/saved_objects/service/lib/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ISavedObjectsRepository", {
  enumerable: true,
  get: function () {
    return _repository.ISavedObjectsRepository;
  }
});
Object.defineProperty(exports, "SavedObjectsRepository", {
  enumerable: true,
  get: function () {
    return _repository.SavedObjectsRepository;
  }
});
Object.defineProperty(exports, "SavedObjectsClientWrapperFactory", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientWrapperFactory;
  }
});
Object.defineProperty(exports, "SavedObjectsClientWrapperOptions", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientWrapperOptions;
  }
});
Object.defineProperty(exports, "ISavedObjectsClientProvider", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.ISavedObjectsClientProvider;
  }
});
Object.defineProperty(exports, "SavedObjectsClientProvider", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientProvider;
  }
});
Object.defineProperty(exports, "SavedObjectsClientProviderOptions", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientProviderOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsClientFactory", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientFactory;
  }
});
Object.defineProperty(exports, "SavedObjectsClientFactoryProvider", {
  enumerable: true,
  get: function () {
    return _scoped_client_provider.SavedObjectsClientFactoryProvider;
  }
});
Object.defineProperty(exports, "SavedObjectsErrorHelpers", {
  enumerable: true,
  get: function () {
    return _errors.SavedObjectsErrorHelpers;
  }
});

var _repository = require("./repository");

var _scoped_client_provider = require("./scoped_client_provider");

var _errors = require("./errors");
